# Exon Py

[![PyPI - Version](https://img.shields.io/pypi/v/exon-py.svg)](https://pypi.org/project/exon-py)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/exon-py.svg)](https://pypi.org/project/exon-py)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install exon-py
```

## License

`exon-py` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
